"use client";

import * as React from "react";
import { TrendingUp } from "lucide-react";
import { Label, Pie, PieChart } from "recharts";

import {
    Card,
    CardContent,
    CardDescription,
    CardFooter,
    CardHeader,
    CardTitle,
} from "@/Components/ui/card";
import {
    type ChartConfig,
    ChartContainer,
    ChartTooltip,
    ChartTooltipContent,
    ChartLegend,
    ChartLegendContent,
} from "@/Components/ui/chart";

interface SiteData {
    name: string;
    total_revenue: number;
}

interface DataPieChartProps {
    data: SiteData[];
}

export function DataPieChart({ data }: DataPieChartProps) {
    // Transform the data to match your original chart format
    const chartData = data.map((site, index) => ({
        browser: site.name,
        visitors: site.total_revenue,
        fill: `hsl(${index * 50}, 84.2%, 60.2%)`, // Assigning unique colors
    }));

    // Create config dynamically based on site names
    const chartConfig = {
        visitors: {
            label: "Revenue ($)",
        },
        ...data.reduce(
            (acc, site, index) => ({
                ...acc,
                [site.name]: {
                    label: site.name,
                    fill: `hsl(${index * 50}, 84.2%, 60.2%)`, // Assigning unique colors
                },
            }),
            {}
        ),
    } satisfies ChartConfig;

    const totalRevenue = React.useMemo(() => {
        return chartData.reduce((acc, curr) => acc + curr.visitors, 0);
    }, [chartData]); // <-- chartData is in the dependency array


    return (
        <Card className="flex flex-col bg-transparent border-none shadow-none">
            <CardHeader className="lg:items-center pb-0 lg:p-6 p-0">
                <CardTitle className="text-green-600 text-2xl font-bold">
                    Site Revenue with Pie Chart
                </CardTitle>
                <CardDescription>Revenue by site</CardDescription>
            </CardHeader>
            <CardContent className="flex-1 pb-0 lg:p-6 p-0">
                <ChartContainer
                    config={chartConfig}
                    className="mx-auto aspect-square max-h-[400px]"
                >
                    <PieChart>
                        <ChartTooltip
                            cursor={false}
                            content={<ChartTooltipContent hideLabel />}
                        />
                        <Pie
                            data={chartData}
                            dataKey="visitors"
                            nameKey="browser"
                            innerRadius={80}
                            strokeWidth={2}
                            label={({ payload, ...props }) => {
                                return (
                                    <text
                                        cx={props.cx}
                                        cy={props.cy}
                                        x={props.x}
                                        y={props.y}
                                        textAnchor={props.textAnchor}
                                        dominantBaseline={
                                            props.dominantBaseline
                                        }
                                        fill="hsla(var(--foreground))"
                                    >
                                        $ {payload.visitors.toLocaleString()}
                                    </text>
                                );
                            }}
                        >
                            <Label
                                content={({ viewBox }) => {
                                    if (
                                        viewBox &&
                                        "cx" in viewBox &&
                                        "cy" in viewBox
                                    ) {
                                        return (
                                            <text
                                                x={viewBox.cx}
                                                y={viewBox.cy}
                                                textAnchor="middle"
                                                dominantBaseline="middle"
                                            >
                                                <tspan
                                                    x={viewBox.cx}
                                                    y={viewBox.cy}
                                                    className="fill-foreground text-3xl font-bold"
                                                >
                                                    {totalRevenue.toLocaleString()}
                                                </tspan>
                                                <tspan
                                                    x={viewBox.cx}
                                                    y={(viewBox.cy || 0) + 24}
                                                    className="fill-muted-foreground"
                                                >
                                                    Total Revenue
                                                </tspan>
                                            </text>
                                        );
                                    }
                                }}
                            />
                        </Pie>
                        <ChartLegend
                            content={<ChartLegendContent nameKey="browser" />}
                            className="-translate-y-2 flex-wrap gap-2 [&>*]:basis-1/4 [&>*]:justify-center mt-3"
                        />
                    </PieChart>
                </ChartContainer>
            </CardContent>
        </Card>
    );
}
